@@ -3,6 +3,10 @@
 #  stringlist.py
 """
 A list of strings that represent lines in a multiline string.
+
+.. versionchanged:: 1.0.0
+
+	:class:`~domdf_python_tools.typing.String` should now be imported from :mod:`domdf_python_tools.typing`.
 """
 #
 #  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -27,36 +31,30 @@ A list of strings that represent lines in a multiline string.
 from contextlib import contextmanager
 from typing import Any, Iterable, Iterator, List, Tuple, Union, cast, overload
 
-# 3rd party
-from typing_extensions import Protocol
-
 # this package
+from domdf_python_tools.doctools import prettify_docstrings
+from domdf_python_tools.typing import String
 from domdf_python_tools.utils import convert_indents
 
-__all__ = ["String", "Indent", "StringList"]
-
-
-class String(Protocol):
-	"""
-	Protocol for classes that implement ``__str__``.
-	"""
-
-	def __str__(self) -> str:
-		...  # pragma: no cover
+__all__ = ["Indent", "StringList"]
 
 
+@prettify_docstrings
 class Indent:
 	"""
 	Represents an indent, having a symbol/type and a size.
+
+	:param size: The indent size.
+	:param type: The indent character.
 	"""
 
-	def __init__(self, size: int = 0, type: str = "\t"):
+	def __init__(self, size: int = 0, type: str = "\t"):  # noqa A002  # pylint: disable=redefined-builtin
 		self.size = int(size)
 		self.type = str(type)
 
 	def __iter__(self) -> Iterator[Union[str, Any]]:
 		"""
-		Returns the size and type of the :class:`~domdf_python_tools.stringlist.Indent`
+		Returns the size and type of the :class:`~domdf_python_tools.stringlist.Indent`.
 		"""
 
 		yield self.size
@@ -65,8 +63,9 @@ class Indent:
 	@property
 	def size(self) -> int:
 		"""
-		The indent size
+		The indent size.
 		"""
+
 		return self._size
 
 	@size.setter
@@ -74,15 +73,15 @@ class Indent:
 		self._size = int(size)
 
 	@property
-	def type(self) -> str:
+	def type(self) -> str:  # noqa A002  # pylint: disable=redefined-builtin
 		"""
-		The indent character
+		The indent character.
 		"""
 
 		return self._type
 
-	@type.setter
-	def type(self, type: str) -> None:
+	@type.setter  # noqa A002  # pylint: disable=redefined-builtin
+	def type(self, type: str) -> None:  # noqa A002  # pylint: disable=redefined-builtin
 		if not str(type):
 			raise ValueError("'type' cannot an empty string.")
 
@@ -116,6 +115,9 @@ class Indent:
 class StringList(List[str]):
 	"""
 	A list of strings that represent lines in a multiline string.
+
+	:param iterable: Content to populate the StringList with.
+	:param convert_indents: Whether indents at the start of lines should be converted.
 	"""
 
 	#: The indent to insert at the beginning of new lines.
@@ -134,22 +136,22 @@ class StringList(List[str]):
 		if isinstance(iterable, str):
 			iterable = iterable.split("\n")
 
-		super().__init__([str(x).strip() for x in iterable])
 		self.indent = Indent()
 		self.convert_indents = convert_indents
+		super().__init__([self._make_line(str(x)) for x in iterable])
 
 	def _make_line(self, line: str) -> str:
-		if not str(self.indent).strip(" \t") and self.convert_indents:
-			if self.indent_type == '\t':
-				line = convert_indents(line, tab_width=1, from_='    ', to='\t')
+		if not str(self.indent_type).strip(" \t") and self.convert_indents:
+			if self.indent_type == "\t":
+				line = convert_indents(line, tab_width=1, from_='    ', to="\t")
 			else:  # pragma: no cover
-				line = convert_indents(line, tab_width=1, from_='\t', to=self.indent_type)
+				line = convert_indents(line, tab_width=1, from_="\t", to=self.indent_type)
 
 		return f"{self.indent}{line}".rstrip()
 
 	def append(self, line: String) -> None:
 		"""
-		Append a line to the end of the StringList.
+		Append a line to the end of the :class:`~domdf_python_tools.stringlist.StringList`.
 
 		:param line:
 		"""
@@ -157,9 +159,38 @@ class StringList(List[str]):
 		for inner_line in str(line).split("\n"):
 			super().append(self._make_line(inner_line))
 
+	def extend(self, iterable: Iterable[String]) -> None:
+		"""
+		Extend the :class:`~domdf_python_tools.stringlist.StringList` with lines from ``iterable``.
+
+		:param iterable: An iterable of string-like objects to add to the end of the
+			:class:`~domdf_python_tools.stringlist.StringList`.
+		"""
+
+		for line in iterable:
+			self.append(line)
+
+	def copy(self) -> "StringList":
+		"""
+		Returns a shallow copy of the :class:`~domdf_python_tools.stringlist.StringList`.
+
+		Equivalent to ``a[:]``.
+		"""
+
+		return self.__class__(super().copy())
+
+	def count_blanklines(self) -> int:
+		"""
+		Returns a count of the blank lines in the :class:`~domdf_python_tools.stringlist.StringList`.
+
+		.. versionadded:: 0.7.1
+		"""
+
+		return self.count('')
+
 	def insert(self, index: int, line: String) -> None:
 		"""
-		Insert a line into the StringList at the given position.
+		Insert a line into the :class:`~domdf_python_tools.stringlist.StringList` at the given position.
 
 		:param index:
 		:param line:
@@ -240,7 +271,7 @@ class StringList(List[str]):
 		"""
 		Sets the size of the indent to insert at the beginning of new lines.
 
-		:param size:
+		:param size: The indent size to use for new lines.
 		"""
 
 		self.indent.size = int(size)
@@ -249,7 +280,7 @@ class StringList(List[str]):
 		"""
 		Sets the type of the indent to insert at the beginning of new lines.
 
-		:param indent_type:
+		:param indent_type: The type of indent to use for new lines.
 		"""
 
 		self.indent.type = str(indent_type)
@@ -258,8 +289,8 @@ class StringList(List[str]):
 		"""
 		Sets the indent to insert at the beginning of new lines.
 
-		:param indent:
-		:param size:
+		:param indent: The :class:`~.Indent` to use for new lines, or the indent type.
+		:param size: If ``indent`` is an indent type, the indent size to use for new lines.
 		"""
 
 		if isinstance(indent, Indent):
@@ -295,7 +326,7 @@ class StringList(List[str]):
 		return str(self.indent.type)
 
 	@indent_type.setter
-	def indent_type(self, type: str) -> None:
+	def indent_type(self, type: str) -> None:  # noqa: A002  # pylint: disable=redefined-builtin
 		"""
 		Sets the indent type.
 		"""
@@ -330,8 +361,8 @@ class StringList(List[str]):
 			>>> with sl.with_indent("    ", 1):
 			...     sl.append("Hello World")
 
-		:param indent:
-		:param size:
+		:param indent: The :class:`~.Indent` to use within the ``with`` block, or the indent type.
+		:param size: If ``indent`` is an indent type, the indent size to use within the ``with`` block.
 		"""
 
 		original_indent: Tuple[int, str] = tuple(self.indent)  # type: ignore
@@ -353,7 +384,7 @@ class StringList(List[str]):
 			>>> with sl.with_indent_size(1):
 			...     sl.append("Hello World")
 
-		:param size:
+		:param size: The indent size to use within the ``with`` block.
 		"""
 
 		original_indent_size = self.indent_size
@@ -375,7 +406,7 @@ class StringList(List[str]):
 			>>> with sl.with_indent_type("    "):
 			...     sl.append("Hello World")
 
-		:param indent_type:
+		:param indent_type: The type of indent to use within the ``with`` block.
 		"""
 
 		original_indent_type = self.indent_type
