@@ -2,15 +2,11 @@
 #
 #  terminal.py
 """
-Useful functions for terminal-based programs
+Useful functions for terminal-based programs.
 """
 #
 #  Copyright © 2014-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
 #
-#  get_terminal_size, _get_terminal_size_windows, _get_terminal_size_tput and _get_terminal_size_posix
-# 		from https://gist.github.com/jtriley/1108174
-#  		Copyright © 2011 jtriley
-#
 #  Parts of the docstrings based on the Python 3.8.2 Documentation
 #  Licensed under the Python Software Foundation License Version 2.
 #  Copyright © 2001-2020 Python Software Foundation. All rights reserved.
@@ -62,13 +58,14 @@ Useful functions for terminal-based programs
 # stdlib
 import inspect
 import os
-import platform
 import pprint
-import shlex
-import struct
-import subprocess
+import shutil
 import textwrap
-from typing import Any, Optional, Tuple
+from typing import IO, Tuple
+
+# this package
+from domdf_python_tools import __version__
+from domdf_python_tools.utils import deprecated
 
 __all__ = [
 		"clear",
@@ -95,7 +92,7 @@ def clear() -> None:
 
 def br() -> None:
 	"""
-	Prints a line break
+	Prints a blank line.
 	"""
 
 	print('')
@@ -107,12 +104,20 @@ def interrupt() -> None:
 
 	Useful when you have a long-running script that you might want to
 	interrupt part way through.
+
+	**Example:**
+
+	.. code-block:: python
+
+		>>> interrupt()
+		(Press Ctrl-C to quit at any time)
+
 	"""
 
-	print(f"(Press Ctrl-{'C' if os.name == 'nt' else 'D'} to quit at any time.)")
+	print(f"(Press Ctrl-{'C' if os.name == 'nt' else 'D'} to quit at any time)")
 
 
-def overtype(*objects, sep: str = ' ', end: str = '', file=None, flush: bool = False) -> None:
+def overtype(*objects, sep: str = ' ', end: str = '', file: IO = None, flush: bool = False) -> None:
 	"""
 	Print ``objects`` to the text stream ``file``, starting with ``"\\r"``, separated by ``sep``
 	and followed by ``end``.
@@ -128,120 +133,33 @@ def overtype(*objects, sep: str = ' ', end: str = '', file=None, flush: bool = F
 
 	:param objects: A list of strings or string-like objects to write to the terminal.
 	:param sep: String to separate the objects with.
-	:type sep: str
 	:param end: String to end with.
-	:type end: str
 	:param file: An object with a ``write(string)`` method.
 	:default file: ``sys.stdout``
-	:type file:
 	:param flush: If true, the stream is forcibly flushed.
-	:type flush: bool
-	"""
+	"""  # noqa D400
 
 	object0 = f"\r{objects[0]}"
 	objects = (object0, *objects[1:])
 	print(*objects, sep=sep, end=end, file=file, flush=flush)
 
 
+@deprecated(
+		deprecated_in="1.0.0",
+		removed_in="2.0.0",
+		current_version=__version__,
+		details="Use :func:`shutil.get_terminal_size` instead.",
+		)
 def get_terminal_size() -> Tuple[int, int]:  # pragma: no cover
 	"""
 	Get width and height of console.
 
 	Works on Linux, macOS, Windows, and Cygwin.
 
-	Based on http://stackoverflow.com/questions/566746/how-to-get-console-window-width-in-python
-
-	:return: tuple_xy
+	:return: Screen width and screen height.
 	"""
 
-	current_os = platform.system()
-	tuple_xy = None
-
-	if current_os == "Windows":
-		tuple_xy = _get_terminal_size_windows()
-		if tuple_xy is None:
-			tuple_xy = _get_terminal_size_tput()
-		# needed for window's python in cygwin's xterm!
-
-	if current_os in {"Linux", "Darwin"} or current_os.startswith("CYGWIN"):
-		tuple_xy = _get_terminal_size_posix()
-
-	if tuple_xy is None:
-		print("default")
-		tuple_xy = (80, 25)  # default value
-
-	return tuple_xy
-
-
-def _get_terminal_size_windows() -> Optional[Tuple[int, int]]:  # pragma: no cover
-	try:
-
-		# stdlib
-		from ctypes import create_string_buffer, windll  # type: ignore
-
-		# stdin handle is -10
-		# stdout handle is -11
-		# stderr handle is -12
-		h = windll.kernel32.GetStdHandle(-12)
-		csbi = create_string_buffer(22)
-		res = windll.kernel32.GetConsoleScreenBufferInfo(h, csbi)
-
-		if res:
-			(buf_x, buf_y, cur_x, cur_y, wattr, left, top, right, bottom, maxx,
-				maxy) = struct.unpack("hhhhHhhhhhh", csbi.raw)
-			size_x = right - left + 1
-			size_y = bottom - top + 1
-
-			return size_x, size_y
-	except Exception:
-		pass
-
-	return None
-
-
-def _get_terminal_size_tput() -> Optional[Tuple[int, int]]:  # pragma: no cover
-	# get terminal width
-	# src: http://stackoverflow.com/questions/263890/how-do-i-find-the-width-height-of-a-terminal-window
-	try:
-		cols = int(subprocess.check_call(shlex.split("tput cols")))
-		rows = int(subprocess.check_call(shlex.split("tput lines")))
-		return cols, rows
-	except Exception:
-		return None
-
-
-def _get_terminal_size_posix() -> Optional[Tuple[int, int]]:  # pragma: no cover
-
-	# stdlib
-	import fcntl
-	import termios
-
-	def ioctl_GWINSZ(fd: int) -> Optional[Tuple[Any, ...]]:
-		try:
-			cr = struct.unpack("hh", fcntl.ioctl(fd, termios.TIOCGWINSZ, b"1234"))
-			return cr
-		except Exception:
-			pass
-
-		return None
-
-	cr = ioctl_GWINSZ(0) or ioctl_GWINSZ(1) or ioctl_GWINSZ(2)
-
-	if not cr:
-		try:
-			fd = os.open(os.ctermid(), os.O_RDONLY)  # type: ignore
-			cr = ioctl_GWINSZ(fd)
-			os.close(fd)
-		except Exception:
-			pass
-
-	if not cr:
-		try:
-			cr = (os.environ["LINES"], os.environ["COLUMNS"])
-		except Exception:
-			return None
-
-	return int(cr[1]), int(cr[0])
+	return shutil.get_terminal_size((80, 25))
 
 
 class Echo:
@@ -249,7 +167,6 @@ class Echo:
 	Context manager for echoing variable assignments (in CPython).
 
 	:param indent: The indentation of the dictionary of variable assignments.
-	:type indent: str, optional
 	"""
 
 	def __init__(self, indent: str = "  "):
@@ -262,9 +179,17 @@ class Echo:
 			self.parent_frame = inspect.currentframe().f_back  # type: ignore  # TODO
 
 	def __enter__(self):
+		"""
+		Called when entering the context manager.
+		"""
+
 		self.locals_on_entry = self.parent_frame.f_locals.copy()  # type: ignore
 
-	def __exit__(self, exc_t, exc_v, tb):
+	def __exit__(self, *args, **kwargs):
+		"""
+		Called when exiting the context manager.
+		"""
+
 		new_locals = {
 				k: v
 				for k,
